@@ -1,4 +1,4 @@
-test_that("empty FSelectInstanceSingleCrit works", {
+test_that("empty FSelectInstanceBatchSingleCrit works", {
   inst = TEST_MAKE_INST_1D()
 
   expect_data_table(inst$archive$data, nrows = 0L)
